==> cloudmonkey-4.0.0.tar.gz: cloudmonkey-4.0.0/cloudmonkey/marvin/cloudstackAPI/addTrafficMonitor.py <==

"""Adds Traffic Monitor Host for Direct Network Usage"""
from baseCmd import *
from baseResponse import *
class addTrafficMonitorCmd (baseCmd):
    def __init__(self):
        self.isAsync = "false"
        """URL of the traffic monitor Host"""
        """Required"""
        self.url = None
        """Zone in which to add the external firewall appliance."""
        """Required"""
        self.zoneid = None
        self.required = ["url","zoneid",]

class addTrafficMonitorResponse (baseResponse):
    def __init__(self):
        """the ID of the external firewall"""
        self.id = None
        """the management IP address of the external firewall"""
        self.ipaddress = None
        """the number of times to retry requests to the external firewall"""
        self.numretries = None
        """the private interface of the external firewall"""
        self.privateinterface = None
        """the private security zone of the external firewall"""
        self.privatezone = None
        """the public interface of the external firewall"""
        self.publicinterface = None
        """the public security zone of the external firewall"""
        self.publiczone = None
        """the timeout (in seconds) for requests to the external firewall"""
        self.timeout = None
        """the usage interface of the external firewall"""
        self.usageinterface = None
        """the username that's used to log in to the external firewall"""
        self.username = None
        """the zone ID of the external firewall"""
        self.zoneid = None

==> cloudmonkey-4.0.0-2.tar.gz: cloudmonkey-4.0.0/cloudmonkey/marvin/cloudstackAPI/addTrafficMonitor.py <==

"""Adds Traffic Monitor Host for Direct Network Usage"""
from baseCmd import *
from baseResponse import *
class addTrafficMonitorCmd (baseCmd):
    def __init__(self):
        self.isAsync = "false"
        """URL of the traffic monitor Host"""
        """Required"""
        self.url = None
        """Zone in which to add the external firewall appliance."""
        """Required"""
        self.zoneid = None
        """Traffic going into the listed zones will not be metered"""
        self.excludezones = None
        """Traffic going into the listed zones will be metered"""
        self.includezones = None
        self.required = ["url","zoneid",]

class addTrafficMonitorResponse (baseResponse):
    def __init__(self):
        """the ID of the external firewall"""
        self.id = None
        """the management IP address of the external firewall"""
        self.ipaddress = None
        """the number of times to retry requests to the external firewall"""
        self.numretries = None
        """the private interface of the external firewall"""
        self.privateinterface = None
        """the private security zone of the external firewall"""
        self.privatezone = None
        """the public interface of the external firewall"""
        self.publicinterface = None
        """the public security zone of the external firewall"""
        self.publiczone = None
        """the timeout (in seconds) for requests to the external firewall"""
        self.timeout = None
        """the usage interface of the external firewall"""
        self.usageinterface = None
        """the username that's used to log in to the external firewall"""
        self.username = None
        """the zone ID of the external firewall"""
        self.zoneid = None
